# Description

This is an example environment with simple tool calls. The example data can be found in `example_single_tool_call/data/example.jsonl`.


# Licensing information
Code: Apache 2.0
Data: Apache 2.0

Dependencies
- nemo_gym: Apache 2.0
